@@ -346,28 +346,25 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 if t.kind == "video":
                     pc.addTrack(video)
 
-            self.channel = pc.createDataChannel("sendChannel")
-            channel_log(self._logger, self.channel, "-", "created by local party")
+            sendchannel = pc.createDataChannel("sendChannel")
+            channel_log(self._logger, sendchannel, "-", "created by local party")
 
-            @self.channel.on("open")
+            @sendchannel.on("open")
             def on_open():
                 self._logger.info("datachannel open")
 
-            @self.channel.on("message")
+            @sendchannel.on("message")
             def on_message(message):
 
                 def subprocess_cmd(command):
                     process = subprocess.Popen(command, stdout=subprocess.PIPE, shell=True)
                     proc_stdout = process.communicate()[0].strip()
-                    # for line in proc_stdout.decode().split('\n'):
-                    channel_send(self._logger, self.channel, json.dumps({"response": proc_stdout.decode()}))
+                    channel_send(self._logger, sendchannel, json.dumps({"response": proc_stdout.decode()}))
 
-                channel_log(self._logger, self.channel, "<", message)
+                channel_log(self._logger, sendchannel, "<", message)
                 if isinstance(message, str) and message.startswith("ping"):
-                    # reply
-                    channel_send(self._logger, self.channel, f'{{"ping":"pong","ts":"{datetime.utcnow()} UTC"}}')
+                    channel_send(self._logger, sendchannel, f'{{"ping":"pong","ts":"{datetime.utcnow()} UTC"}}')
                 if isinstance(message, str) and message.startswith('{"type'):
-                    # reply
                     self.oncommand(self.gsdbs, json.loads(message))
                 if isinstance(message, str) and message.startswith('{"command'):
                     subprocess_cmd(json.loads(message)["command"])
