@@ -4,7 +4,7 @@ import json
 import logging
 from strenum import StrEnum
 import socketio
-from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration
+from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration, RTCSessionDescription
 from aiortc.contrib.media import MediaRelay, MediaBlackhole
 from aiortc.mediastreams import MediaStreamError
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
@@ -188,17 +188,13 @@ class GSPeerConnectionWatcherNew:
                 self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
                 self.peerConnections = RTCPeerConnection()
+            if type(description) == str:
+                description = ast.literal_eval(description)
+
+            offer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
             self.peerConnections.addTransceiver('video', direction='recvonly')
 
-            @self.peerConnections.on("iceconnectionstatechange")
-            async def on_iceconnectionstatechange():
-                if self.peerConnections.iceConnectionState == "complete":
-                    pass
-
-                if self.peerConnections.iceConnectionState == "failed":
-                    await self.peerConnections.close()
-
             @self.peerConnections.on("track")
             async def on_track(track):
                 if track.kind == "video":
@@ -211,21 +207,12 @@ class GSPeerConnectionWatcherNew:
                         gsmediaconsumer.addTrack(track)
                         await gsmediaconsumer.start()
 
-            await self.peerConnections.setRemoteDescription(description)
+            await self.peerConnections.setRemoteDescription(offer)
             await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
-
             await self.sio.emit("answer",
-                                {"target": self.target,
-                                 "sdp": {"type": self.peerConnections.localDescription.type,
-                                         "sdp": self.peerConnections.localDescription.sdp}})
-
-        @self.sio.event
-        async def answer(id, description):
-            if isinstance(description, dict):
-                desc = type('new_dict', (object,), description)
-            else:
-                desc = type('new_dict', (object,), ast.literal_eval(description))
-            await self.peerConnections.setRemoteDescription(desc)
+                                {"id": id,
+                                 "message": {"type": self.peerConnections.localDescription.type,
+                                             "sdp": self.peerConnections.localDescription.sdp}})
 
         @self.sio.event
         async def disconnect(id, target):
